#
# imap.py -- intensity maps for fits viewing
# 
# Eric Jeschke (eric@naoj.org)
#
# Copyright (c) Eric R. Jeschke.  All rights reserved.
# This is open-source software licensed under a BSD license.
# Please see the file LICENSE.txt for details.
#
import numpy

# Some built in intensity maps

imap_equa = (
                   0.06275,
                   0.13725,
                   0.22353,
                   0.30196,
                   0.36078,
                   0.41176,
                   0.46275,
                   0.50588,
                   0.54510,
                   0.57647,
                   0.60392,
                   0.62745,
                   0.64706,
                   0.66275,
                   0.68235,
                   0.69412,
                   0.70588,
                   0.71765,
                   0.72941,
                   0.73725,
                   0.74510,
                   0.75686,
                   0.76471,
                   0.76863,
                   0.77647,
                   0.78039,
                   0.78824,
                   0.79216,
                   0.79608,
                   0.80000,
                   0.80392,
                   0.80784,
                   0.81176,
                   0.81569,
                   0.81961,
                   0.82353,
                   0.82745,
                   0.83137,
                   0.83529,
                   0.83922,
                   0.84314,
                   0.84314,
                   0.84706,
                   0.85098,
                   0.85490,
                   0.85882,
                   0.85882,
                   0.86275,
                   0.86667,
                   0.86667,
                   0.87059,
                   0.87451,
                   0.87451,
                   0.87843,
                   0.87843,
                   0.88235,
                   0.88235,
                   0.88627,
                   0.88627,
                   0.89020,
                   0.89020,
                   0.89412,
                   0.89412,
                   0.89804,
                   0.89804,
                   0.90196,
                   0.90196,
                   0.90588,
                   0.90588,
                   0.90980,
                   0.90980,
                   0.91373,
                   0.91373,
                   0.91765,
                   0.91765,
                   0.92157,
                   0.92157,
                   0.92549,
                   0.92549,
                   0.92941,
                   0.92941,
                   0.93333,
                   0.93333,
                   0.93725,
                   0.93725,
                   0.93725,
                   0.94118,
                   0.94118,
                   0.94510,
                   0.94510,
                   0.94510,
                   0.94902,
                   0.94902,
                   0.95294,
                   0.95294,
                   0.95294,
                   0.95686,
                   0.95686,
                   0.95686,
                   0.96078,
                   0.96078,
                   0.96078,
                   0.96471,
                   0.96471,
                   0.96471,
                   0.96471,
                   0.96863,
                   0.96863,
                   0.96863,
                   0.96863,
                   0.97255,
                   0.97255,
                   0.97255,
                   0.97255,
                   0.97255,
                   0.97255,
                   0.97647,
                   0.97647,
                   0.97647,
                   0.97647,
                   0.97647,
                   0.97647,
                   0.98039,
                   0.98039,
                   0.98039,
                   0.98039,
                   0.98039,
                   0.98039,
                   0.98039,
                   0.98039,
                   0.98039,
                   0.98039,
                   0.98431,
                   0.98431,
                   0.98431,
                   0.98431,
                   0.98431,
                   0.98431,
                   0.98431,
                   0.98431,
                   0.98431,
                   0.98431,
                   0.98431,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.98824,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99216,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   0.99608,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   1.00000,
                   )

imap_ultrasmooth = (
    0.0,
    0.00392156862745,
    0.0078431372549,
    0.0117647058824,
    0.0156862745098,
    0.0196078431373,
    0.0235294117647,
    0.0274509803922,
    0.0313725490196,
    0.0352941176471,
    0.0392156862745,
    0.043137254902,
    0.0470588235294,
    0.0509803921569,
    0.0549019607843,
    0.0588235294118,
    0.0627450980392,
    0.0666666666667,
    0.0705882352941,
    0.0745098039216,
    0.078431372549,
    0.0823529411765,
    0.0862745098039,
    0.0901960784314,
    0.0941176470588,
    0.0980392156863,
    0.101960784314,
    0.105882352941,
    0.109803921569,
    0.113725490196,
    0.117647058824,
    0.121568627451,
    0.125490196078,
    0.129411764706,
    0.133333333333,
    0.137254901961,
    0.141176470588,
    0.145098039216,
    0.149019607843,
    0.152941176471,
    0.156862745098,
    0.160784313725,
    0.164705882353,
    0.16862745098,
    0.172549019608,
    0.176470588235,
    0.180392156863,
    0.18431372549,
    0.188235294118,
    0.192156862745,
    0.196078431373,
    0.2,
    0.203921568627,
    0.207843137255,
    0.211764705882,
    0.21568627451,
    0.219607843137,
    0.223529411765,
    0.227450980392,
    0.23137254902,
    0.235294117647,
    0.239215686275,
    0.243137254902,
    0.247058823529,
    0.250980392157,
    0.254901960784,
    0.258823529412,
    0.262745098039,
    0.266666666667,
    0.270588235294,
    0.274509803922,
    0.278431372549,
    0.282352941176,
    0.286274509804,
    0.290196078431,
    0.294117647059,
    0.298039215686,
    0.301960784314,
    0.305882352941,
    0.309803921569,
    0.313725490196,
    0.317647058824,
    0.321568627451,
    0.325490196078,
    0.329411764706,
    0.333333333333,
    0.337254901961,
    0.341176470588,
    0.345098039216,
    0.349019607843,
    0.352941176471,
    0.356862745098,
    0.360784313725,
    0.364705882353,
    0.36862745098,
    0.372549019608,
    0.376470588235,
    0.380392156863,
    0.38431372549,
    0.388235294118,
    0.392156862745,
    0.396078431373,
    0.4,
    0.403921568627,
    0.407843137255,
    0.411764705882,
    0.41568627451,
    0.419607843137,
    0.423529411765,
    0.427450980392,
    0.43137254902,
    0.435294117647,
    0.439215686275,
    0.443137254902,
    0.447058823529,
    0.450980392157,
    0.454901960784,
    0.458823529412,
    0.462745098039,
    0.466666666667,
    0.470588235294,
    0.474509803922,
    0.478431372549,
    0.482352941176,
    0.486274509804,
    0.490196078431,
    0.494117647059,
    0.498039215686,
    0.501960784314,
    0.505882352941,
    0.509803921569,
    0.513725490196,
    0.517647058824,
    0.521568627451,
    0.525490196078,
    0.529411764706,
    0.533333333333,
    0.537254901961,
    0.541176470588,
    0.545098039216,
    0.549019607843,
    0.552941176471,
    0.556862745098,
    0.560784313725,
    0.564705882353,
    0.56862745098,
    0.572549019608,
    0.576470588235,
    0.580392156863,
    0.58431372549,
    0.588235294118,
    0.592156862745,
    0.596078431373,
    0.6,
    0.603921568627,
    0.607843137255,
    0.611764705882,
    0.61568627451,
    0.619607843137,
    0.623529411765,
    0.627450980392,
    0.63137254902,
    0.635294117647,
    0.639215686275,
    0.643137254902,
    0.647058823529,
    0.650980392157,
    0.654901960784,
    0.658823529412,
    0.662745098039,
    0.666666666667,
    0.670588235294,
    0.674509803922,
    0.678431372549,
    0.682352941176,
    0.686274509804,
    0.690196078431,
    0.694117647059,
    0.698039215686,
    0.701960784314,
    0.705882352941,
    0.709803921569,
    0.713725490196,
    0.717647058824,
    0.721568627451,
    0.725490196078,
    0.729411764706,
    0.733333333333,
    0.737254901961,
    0.741176470588,
    0.745098039216,
    0.749019607843,
    0.752941176471,
    0.756862745098,
    0.760784313725,
    0.764705882353,
    0.76862745098,
    0.772549019608,
    0.776470588235,
    0.780392156863,
    0.78431372549,
    0.788235294118,
    0.792156862745,
    0.796078431373,
    0.8,
    0.803921568627,
    0.807843137255,
    0.811764705882,
    0.81568627451,
    0.819607843137,
    0.823529411765,
    0.827450980392,
    0.83137254902,
    0.835294117647,
    0.839215686275,
    0.843137254902,
    0.847058823529,
    0.850980392157,
    0.854901960784,
    0.858823529412,
    0.862745098039,
    0.866666666667,
    0.870588235294,
    0.874509803922,
    0.878431372549,
    0.882352941176,
    0.886274509804,
    0.890196078431,
    0.894117647059,
    0.898039215686,
    0.901960784314,
    0.905882352941,
    0.909803921569,
    0.913725490196,
    0.917647058824,
    0.921568627451,
    0.925490196078,
    0.929411764706,
    0.933333333333,
    0.937254901961,
    0.941176470588,
    0.945098039216,
    0.949019607843,
    0.952941176471,
    0.956862745098,
    0.960784313725,
    0.964705882353,
    0.96862745098,
    0.972549019608,
    0.976470588235,
    0.980392156863,
    0.98431372549,
    0.988235294118,
    0.992156862745,
    0.996078431373,
    1.0,
    )    

imap_lasritt = (
                0.05882,
                0.12157,
                0.18431,
                0.24706,
                0.30980,
                0.37255,
                0.43529,
                0.49804,
                0.56078,
                0.62353,
                0.68627,
                0.74902,
                0.81176,
                0.87451,
                0.93725,
                1.00000,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.12157,
                0.12157,
                0.12157,
                0.12157,
                0.12157,
                0.12157,
                0.12157,
                0.12157,
                0.18431,
                0.18431,
                0.18431,
                0.18431,
                0.18431,
                0.18431,
                0.18431,
                0.18431,
                0.24706,
                0.24706,
                0.24706,
                0.24706,
                0.24706,
                0.24706,
                0.24706,
                0.24706,
                0.30980,
                0.30980,
                0.30980,
                0.30980,
                0.30980,
                0.30980,
                0.30980,
                0.30980,
                0.37255,
                0.37255,
                0.37255,
                0.37255,
                0.37255,
                0.37255,
                0.37255,
                0.37255,
                0.43529,
                0.43529,
                0.43529,
                0.43529,
                0.43529,
                0.43529,
                0.43529,
                0.43529,
                0.49804,
                0.49804,
                0.49804,
                0.49804,
                0.49804,
                0.49804,
                0.49804,
                0.49804,
                0.56078,
                0.56078,
                0.56078,
                0.56078,
                0.56078,
                0.56078,
                0.56078,
                0.56078,
                0.62353,
                0.62353,
                0.62353,
                0.62353,
                0.62353,
                0.62353,
                0.62353,
                0.62353,
                0.68627,
                0.68627,
                0.68627,
                0.68627,
                0.68627,
                0.68627,
                0.68627,
                0.68627,
                0.74902,
                0.74902,
                0.74902,
                0.74902,
                0.74902,
                0.74902,
                0.74902,
                0.74902,
                0.81176,
                0.81176,
                0.81176,
                0.81176,
                0.81176,
                0.81176,
                0.81176,
                0.81176,
                0.87451,
                0.87451,
                0.87451,
                0.87451,
                0.87451,
                0.87451,
                0.87451,
                0.87451,
                0.93725,
                0.93725,
                0.93725,
                0.93725,
                0.93725,
                0.93725,
                0.93725,
                0.93725,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.12157,
                0.12157,
                0.12157,
                0.12157,
                0.12157,
                0.12157,
                0.12157,
                0.18431,
                0.18431,
                0.18431,
                0.18431,
                0.18431,
                0.18431,
                0.18431,
                0.24706,
                0.24706,
                0.24706,
                0.24706,
                0.24706,
                0.24706,
                0.24706,
                0.30980,
                0.30980,
                0.30980,
                0.30980,
                0.30980,
                0.30980,
                0.30980,
                0.37255,
                0.37255,
                0.37255,
                0.37255,
                0.37255,
                0.37255,
                0.37255,
                0.43529,
                0.43529,
                0.43529,
                0.43529,
                0.43529,
                0.43529,
                0.43529,
                0.49804,
                0.49804,
                0.49804,
                0.49804,
                0.49804,
                0.49804,
                0.49804,
                0.56078,
                0.56078,
                0.56078,
                0.56078,
                0.56078,
                0.56078,
                0.56078,
                0.62353,
                0.62353,
                0.62353,
                0.62353,
                0.62353,
                0.62353,
                0.62353,
                0.68627,
                0.68627,
                0.68627,
                0.68627,
                0.68627,
                0.68627,
                0.68627,
                0.74902,
                0.74902,
                0.74902,
                0.74902,
                0.74902,
                0.74902,
                0.74902,
                0.81176,
                0.81176,
                0.81176,
                0.81176,
                0.81176,
                0.81176,
                0.81176,
                0.87451,
                0.87451,
                0.87451,
                0.87451,
                0.87451,
                0.87451,
                0.87451,
                0.93725,
                0.93725,
                0.93725,
                0.93725,
                0.93725,
                0.93725,
                0.93725,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
        )

imap_expo = (
                0.00458,
                0.00689,
                0.00920,
                0.01152,
                0.01386,
                0.01620,
                0.01855,
                0.02091,
                0.02328,
                0.02565,
                0.02804,
                0.03044,
                0.03285,
                0.03526,
                0.03769,
                0.04012,
                0.04257,
                0.04502,
                0.04748,
                0.04996,
                0.05244,
                0.05493,
                0.05743,
                0.05995,
                0.06247,
                0.06500,
                0.06754,
                0.07010,
                0.07266,
                0.07523,
                0.07781,
                0.08041,
                0.08301,
                0.08562,
                0.08824,
                0.09088,
                0.09352,
                0.09618,
                0.09884,
                0.10152,
                0.10420,
                0.10690,
                0.10960,
                0.11232,
                0.11505,
                0.11779,
                0.12054,
                0.12330,
                0.12607,
                0.12885,
                0.13164,
                0.13445,
                0.13726,
                0.14009,
                0.14293,
                0.14578,
                0.14863,
                0.15151,
                0.15439,
                0.15728,
                0.16019,
                0.16310,
                0.16603,
                0.16897,
                0.17192,
                0.17488,
                0.17786,
                0.18084,
                0.18384,
                0.18685,
                0.18987,
                0.19290,
                0.19595,
                0.19900,
                0.20207,
                0.20515,
                0.20824,
                0.21135,
                0.21447,
                0.21760,
                0.22074,
                0.22389,
                0.22706,
                0.23024,
                0.23343,
                0.23663,
                0.23985,
                0.24308,
                0.24632,
                0.24957,
                0.25284,
                0.25612,
                0.25942,
                0.26272,
                0.26604,
                0.26937,
                0.27272,
                0.27608,
                0.27945,
                0.28283,
                0.28623,
                0.28964,
                0.29307,
                0.29651,
                0.29996,
                0.30342,
                0.30690,
                0.31039,
                0.31390,
                0.31742,
                0.32095,
                0.32450,
                0.32806,
                0.33164,
                0.33523,
                0.33883,
                0.34245,
                0.34608,
                0.34973,
                0.35339,
                0.35707,
                0.36076,
                0.36446,
                0.36818,
                0.37191,
                0.37566,
                0.37942,
                0.38320,
                0.38699,
                0.39080,
                0.39462,
                0.39846,
                0.40231,
                0.40618,
                0.41006,
                0.41396,
                0.41788,
                0.42180,
                0.42575,
                0.42971,
                0.43368,
                0.43767,
                0.44168,
                0.44570,
                0.44974,
                0.45379,
                0.45786,
                0.46195,
                0.46605,
                0.47017,
                0.47430,
                0.47845,
                0.48262,
                0.48680,
                0.49100,
                0.49522,
                0.49945,
                0.50370,
                0.50797,
                0.51225,
                0.51655,
                0.52087,
                0.52520,
                0.52955,
                0.53392,
                0.53830,
                0.54270,
                0.54712,
                0.55156,
                0.55601,
                0.56048,
                0.56497,
                0.56948,
                0.57400,
                0.57855,
                0.58311,
                0.58768,
                0.59228,
                0.59689,
                0.60153,
                0.60618,
                0.61085,
                0.61553,
                0.62024,
                0.62496,
                0.62970,
                0.63447,
                0.63925,
                0.64404,
                0.64886,
                0.65370,
                0.65855,
                0.66343,
                0.66832,
                0.67323,
                0.67817,
                0.68312,
                0.68809,
                0.69308,
                0.69809,
                0.70312,
                0.70817,
                0.71324,
                0.71833,
                0.72344,
                0.72856,
                0.73371,
                0.73888,
                0.74407,
                0.74928,
                0.75451,
                0.75977,
                0.76504,
                0.77033,
                0.77564,
                0.78098,
                0.78633,
                0.79171,
                0.79711,
                0.80253,
                0.80797,
                0.81343,
                0.81891,
                0.82442,
                0.82994,
                0.83549,
                0.84106,
                0.84665,
                0.85226,
                0.85790,
                0.86356,
                0.86924,
                0.87494,
                0.88066,
                0.88641,
                0.89218,
                0.89797,
                0.90379,
                0.90963,
                0.91549,
                0.92137,
                0.92728,
                0.93321,
                0.93916,
                0.94514,
                0.95114,
                0.95716,
                0.96321,
                0.96928,
                0.97538,
                0.98150,
                0.98764,
                0.99381,
                0.99888,
                1.00000,
                1.00000,
        )

imap_jigsaw = (
                0.00000,
                0.01569,
                0.03137,
                0.04706,
                0.06275,
                0.07843,
                0.09412,
                0.10980,
                0.12549,
                0.14118,
                0.15686,
                0.17255,
                0.18824,
                0.20392,
                0.21961,
                0.23529,
                0.25098,
                0.26667,
                0.28235,
                0.29804,
                0.31373,
                0.33333,
                0.34902,
                0.36471,
                0.38039,
                0.39608,
                0.41176,
                0.42745,
                0.44314,
                0.45882,
                0.47451,
                0.49020,
                0.50588,
                0.52157,
                0.53725,
                0.55294,
                0.56863,
                0.58431,
                0.60000,
                0.61569,
                0.63137,
                0.64706,
                0.66667,
                0.68235,
                0.69804,
                0.71373,
                0.72941,
                0.74510,
                0.76078,
                0.77647,
                0.79216,
                0.80784,
                0.82353,
                0.83922,
                0.85490,
                0.87059,
                0.88627,
                0.90196,
                0.91765,
                0.93333,
                0.94902,
                0.96471,
                0.98039,
                0.99608,
                0.00000,
                0.01569,
                0.03137,
                0.04706,
                0.06275,
                0.07843,
                0.09412,
                0.10980,
                0.12549,
                0.14118,
                0.15686,
                0.17255,
                0.18824,
                0.20392,
                0.21961,
                0.23529,
                0.25098,
                0.26667,
                0.28235,
                0.29804,
                0.31373,
                0.33333,
                0.34902,
                0.36471,
                0.38039,
                0.39608,
                0.41176,
                0.42745,
                0.44314,
                0.45882,
                0.47451,
                0.49020,
                0.50588,
                0.52157,
                0.53725,
                0.55294,
                0.56863,
                0.58431,
                0.60000,
                0.61569,
                0.63137,
                0.64706,
                0.66667,
                0.68235,
                0.69804,
                0.71373,
                0.72941,
                0.74510,
                0.76078,
                0.77647,
                0.79216,
                0.80784,
                0.82353,
                0.83922,
                0.85490,
                0.87059,
                0.88627,
                0.90196,
                0.91765,
                0.93333,
                0.94902,
                0.96471,
                0.98039,
                0.99608,
                0.00000,
                0.01569,
                0.03137,
                0.04706,
                0.06275,
                0.07843,
                0.09412,
                0.10980,
                0.12549,
                0.14118,
                0.15686,
                0.17255,
                0.18824,
                0.20392,
                0.21961,
                0.23529,
                0.25098,
                0.26667,
                0.28235,
                0.29804,
                0.31373,
                0.33333,
                0.34902,
                0.36471,
                0.38039,
                0.39608,
                0.41176,
                0.42745,
                0.44314,
                0.45882,
                0.47451,
                0.49020,
                0.50588,
                0.52157,
                0.53725,
                0.55294,
                0.56863,
                0.58431,
                0.60000,
                0.61569,
                0.63137,
                0.64706,
                0.66667,
                0.68235,
                0.69804,
                0.71373,
                0.72941,
                0.74510,
                0.76078,
                0.77647,
                0.79216,
                0.80784,
                0.82353,
                0.83922,
                0.85490,
                0.87059,
                0.88627,
                0.90196,
                0.91765,
                0.93333,
                0.94902,
                0.96471,
                0.98039,
                0.99608,
                0.00000,
                0.01569,
                0.03137,
                0.04706,
                0.06275,
                0.07843,
                0.09412,
                0.10980,
                0.12549,
                0.14118,
                0.15686,
                0.17255,
                0.18824,
                0.20392,
                0.21961,
                0.23529,
                0.25098,
                0.26667,
                0.28235,
                0.29804,
                0.31373,
                0.33333,
                0.34902,
                0.36471,
                0.38039,
                0.39608,
                0.41176,
                0.42745,
                0.44314,
                0.45882,
                0.47451,
                0.49020,
                0.50588,
                0.52157,
                0.53725,
                0.55294,
                0.56863,
                0.58431,
                0.60000,
                0.61569,
                0.63137,
                0.64706,
                0.66667,
                0.68235,
                0.69804,
                0.71373,
                0.72941,
                0.74510,
                0.76078,
                0.77647,
                0.79216,
                0.80784,
                0.82353,
                0.83922,
                0.85490,
                0.87059,
                0.88627,
                0.90196,
                0.91765,
                0.93333,
                0.94902,
                0.96471,
                0.98039,
                0.99608,
        )

imap_ramp = (
                0.00000,
                0.00392,
                0.00784,
                0.01176,
                0.01569,
                0.01961,
                0.02353,
                0.02745,
                0.03137,
                0.03529,
                0.03922,
                0.04314,
                0.04706,
                0.05098,
                0.05490,
                0.05882,
                0.06275,
                0.06667,
                0.07059,
                0.07451,
                0.07843,
                0.08235,
                0.08627,
                0.09020,
                0.09412,
                0.09804,
                0.10196,
                0.10588,
                0.10980,
                0.11373,
                0.11765,
                0.12157,
                0.12549,
                0.12941,
                0.13333,
                0.13725,
                0.14118,
                0.14510,
                0.14902,
                0.15294,
                0.15686,
                0.16078,
                0.16471,
                0.16863,
                0.17255,
                0.17647,
                0.18039,
                0.18431,
                0.18824,
                0.19216,
                0.19608,
                0.20000,
                0.20392,
                0.20784,
                0.21176,
                0.21569,
                0.21961,
                0.22353,
                0.22745,
                0.23137,
                0.23529,
                0.23922,
                0.24314,
                0.24706,
                0.25098,
                0.25490,
                0.25882,
                0.26275,
                0.26667,
                0.27059,
                0.27451,
                0.27843,
                0.28235,
                0.28627,
                0.29020,
                0.29412,
                0.29804,
                0.30196,
                0.30588,
                0.30980,
                0.31373,
                0.31765,
                0.32157,
                0.32549,
                0.32941,
                0.33333,
                0.33725,
                0.34118,
                0.34510,
                0.34902,
                0.35294,
                0.35686,
                0.36078,
                0.36471,
                0.36863,
                0.37255,
                0.37647,
                0.38039,
                0.38431,
                0.38824,
                0.39216,
                0.39608,
                0.40000,
                0.40392,
                0.40784,
                0.41176,
                0.41569,
                0.41961,
                0.42353,
                0.42745,
                0.43137,
                0.43529,
                0.43922,
                0.44314,
                0.44706,
                0.45098,
                0.45490,
                0.45882,
                0.46275,
                0.46667,
                0.47059,
                0.47451,
                0.47843,
                0.48235,
                0.48627,
                0.49020,
                0.49412,
                0.49804,
                0.50196,
                0.50588,
                0.50980,
                0.51373,
                0.51765,
                0.52157,
                0.52549,
                0.52941,
                0.53333,
                0.53725,
                0.54118,
                0.54510,
                0.54902,
                0.55294,
                0.55686,
                0.56078,
                0.56471,
                0.56863,
                0.57255,
                0.57647,
                0.58039,
                0.58431,
                0.58824,
                0.59608,
                0.60000,
                0.59608,
                0.60392,
                0.60784,
                0.61176,
                0.61569,
                0.61961,
                0.62353,
                0.62745,
                0.63137,
                0.63529,
                0.63922,
                0.64314,
                0.64706,
                0.65098,
                0.65490,
                0.65882,
                0.66275,
                0.66667,
                0.67059,
                0.67451,
                0.67843,
                0.68235,
                0.68627,
                0.69020,
                0.69412,
                0.69804,
                0.70196,
                0.70588,
                0.70980,
                0.71373,
                0.71765,
                0.72157,
                0.72549,
                0.72941,
                0.73333,
                0.73725,
                0.74118,
                0.74510,
                0.74902,
                0.75294,
                0.75686,
                0.76078,
                0.76471,
                0.76863,
                0.77255,
                0.77647,
                0.78039,
                0.78431,
                0.78824,
                0.79216,
                0.79608,
                0.80000,
                0.80392,
                0.80784,
                0.81176,
                0.81569,
                0.81961,
                0.82353,
                0.82745,
                0.83137,
                0.83529,
                0.83922,
                0.84314,
                0.84706,
                0.85098,
                0.85490,
                0.85882,
                0.86275,
                0.86667,
                0.87059,
                0.87451,
                0.87843,
                0.88235,
                0.88627,
                0.89020,
                0.89412,
                0.89804,
                0.90196,
                0.90588,
                0.90980,
                0.91373,
                0.91765,
                0.92157,
                0.92549,
                0.92941,
                0.93333,
                0.93725,
                0.94118,
                0.94510,
                0.94902,
                0.95294,
                0.95686,
                0.96078,
                0.96471,
                0.96863,
                0.97255,
                0.97647,
                0.98039,
                0.98431,
                0.98824,
                0.99216,
                0.99608,
                1.00000,
        )

imap_neg = (
                1.00000,
                0.99608,
                0.99216,
                0.98824,
                0.98431,
                0.98039,
                0.97647,
                0.97255,
                0.96863,
                0.96471,
                0.96078,
                0.95686,
                0.95294,
                0.94902,
                0.94510,
                0.94118,
                0.93725,
                0.93333,
                0.92941,
                0.92549,
                0.92157,
                0.91765,
                0.91373,
                0.90980,
                0.90588,
                0.90196,
                0.89804,
                0.89412,
                0.89020,
                0.88627,
                0.88235,
                0.87843,
                0.87451,
                0.87059,
                0.86667,
                0.86275,
                0.85882,
                0.85490,
                0.85098,
                0.84706,
                0.84314,
                0.83922,
                0.83529,
                0.83137,
                0.82745,
                0.82353,
                0.81961,
                0.81569,
                0.81176,
                0.80784,
                0.80392,
                0.80000,
                0.79608,
                0.79216,
                0.78824,
                0.78431,
                0.78039,
                0.77647,
                0.77255,
                0.76863,
                0.76471,
                0.76078,
                0.75686,
                0.75294,
                0.74902,
                0.74510,
                0.74118,
                0.73725,
                0.73333,
                0.72941,
                0.72549,
                0.72157,
                0.71765,
                0.71373,
                0.70980,
                0.70588,
                0.70196,
                0.69804,
                0.69412,
                0.69020,
                0.68627,
                0.68235,
                0.67843,
                0.67451,
                0.67059,
                0.66667,
                0.66275,
                0.65882,
                0.65490,
                0.65098,
                0.64706,
                0.64314,
                0.63922,
                0.63529,
                0.63137,
                0.62745,
                0.62353,
                0.61961,
                0.61569,
                0.61176,
                0.60784,
                0.60392,
                0.60000,
                0.59608,
                0.59216,
                0.58824,
                0.58431,
                0.58039,
                0.57647,
                0.57255,
                0.56863,
                0.56471,
                0.56078,
                0.55686,
                0.55294,
                0.54902,
                0.54510,
                0.54118,
                0.53725,
                0.53333,
                0.52941,
                0.52549,
                0.52157,
                0.51765,
                0.51373,
                0.50980,
                0.50588,
                0.50196,
                0.49804,
                0.49412,
                0.49020,
                0.48627,
                0.48235,
                0.47843,
                0.47451,
                0.47059,
                0.46667,
                0.46275,
                0.45882,
                0.45490,
                0.45098,
                0.44706,
                0.44314,
                0.43922,
                0.43529,
                0.43137,
                0.42745,
                0.42353,
                0.41961,
                0.41569,
                0.41176,
                0.40784,
                0.40392,
                0.40000,
                0.39608,
                0.39216,
                0.38824,
                0.38431,
                0.38039,
                0.37647,
                0.37255,
                0.36863,
                0.36471,
                0.36078,
                0.35686,
                0.35294,
                0.34902,
                0.34510,
                0.34118,
                0.33725,
                0.33333,
                0.32941,
                0.32549,
                0.32157,
                0.31765,
                0.31373,
                0.30980,
                0.30588,
                0.30196,
                0.29804,
                0.29412,
                0.29020,
                0.28627,
                0.28235,
                0.27843,
                0.27451,
                0.27059,
                0.26667,
                0.26275,
                0.25882,
                0.25490,
                0.25098,
                0.24706,
                0.24314,
                0.23922,
                0.23529,
                0.23137,
                0.22745,
                0.22353,
                0.21961,
                0.21569,
                0.21176,
                0.20784,
                0.20392,
                0.20000,
                0.19608,
                0.19216,
                0.18824,
                0.18431,
                0.18039,
                0.17647,
                0.17255,
                0.16863,
                0.16471,
                0.16078,
                0.15686,
                0.15294,
                0.14902,
                0.14510,
                0.14118,
                0.13725,
                0.13333,
                0.12941,
                0.12549,
                0.12157,
                0.11765,
                0.11373,
                0.10980,
                0.10588,
                0.10196,
                0.09804,
                0.09412,
                0.09020,
                0.08627,
                0.08235,
                0.07843,
                0.07451,
                0.07059,
                0.06667,
                0.06275,
                0.05882,
                0.05490,
                0.05098,
                0.04706,
                0.04314,
                0.03922,
                0.03529,
                0.03137,
                0.02745,
                0.02353,
                0.01961,
                0.01569,
                0.01176,
                0.00784,
                0.00392,
                0.00000,
        )

imap_stairs = (
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.11765,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.17647,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.23529,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.29412,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.35294,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.41176,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.47059,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.52941,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.58824,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.64706,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.70588,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.76471,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.82353,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.88235,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                1.00000,
                1.00000,
        )

iamp_equa = (
                0.06275,
                0.13725,
                0.22353,
                0.30196,
                0.36078,
                0.41176,
                0.46275,
                0.50588,
                0.54510,
                0.57647,
                0.60392,
                0.62745,
                0.64706,
                0.66275,
                0.68235,
                0.69412,
                0.70588,
                0.71765,
                0.72941,
                0.73725,
                0.74510,
                0.75686,
                0.76471,
                0.76863,
                0.77647,
                0.78039,
                0.78824,
                0.79216,
                0.79608,
                0.80000,
                0.80392,
                0.80784,
                0.81176,
                0.81569,
                0.81961,
                0.82353,
                0.82745,
                0.83137,
                0.83529,
                0.83922,
                0.84314,
                0.84314,
                0.84706,
                0.85098,
                0.85490,
                0.85882,
                0.85882,
                0.86275,
                0.86667,
                0.86667,
                0.87059,
                0.87451,
                0.87451,
                0.87843,
                0.87843,
                0.88235,
                0.88235,
                0.88627,
                0.88627,
                0.89020,
                0.89020,
                0.89412,
                0.89412,
                0.89804,
                0.89804,
                0.90196,
                0.90196,
                0.90588,
                0.90588,
                0.90980,
                0.90980,
                0.91373,
                0.91373,
                0.91765,
                0.91765,
                0.92157,
                0.92157,
                0.92549,
                0.92549,
                0.92941,
                0.92941,
                0.93333,
                0.93333,
                0.93725,
                0.93725,
                0.93725,
                0.94118,
                0.94118,
                0.94510,
                0.94510,
                0.94510,
                0.94902,
                0.94902,
                0.95294,
                0.95294,
                0.95294,
                0.95686,
                0.95686,
                0.95686,
                0.96078,
                0.96078,
                0.96078,
                0.96471,
                0.96471,
                0.96471,
                0.96471,
                0.96863,
                0.96863,
                0.96863,
                0.96863,
                0.97255,
                0.97255,
                0.97255,
                0.97255,
                0.97255,
                0.97255,
                0.97647,
                0.97647,
                0.97647,
                0.97647,
                0.97647,
                0.97647,
                0.98039,
                0.98039,
                0.98039,
                0.98039,
                0.98039,
                0.98039,
                0.98039,
                0.98039,
                0.98039,
                0.98039,
                0.98431,
                0.98431,
                0.98431,
                0.98431,
                0.98431,
                0.98431,
                0.98431,
                0.98431,
                0.98431,
                0.98431,
                0.98431,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
                1.00000,
        )

imap_neglog = (
                1.00000,
                0.98039,
                0.94510,
                0.91373,
                0.89020,
                0.86275,
                0.84314,
                0.81961,
                0.80000,
                0.78431,
                0.76471,
                0.74902,
                0.73725,
                0.71765,
                0.70588,
                0.69412,
                0.68235,
                0.66667,
                0.65882,
                0.64706,
                0.63922,
                0.62745,
                0.61569,
                0.60784,
                0.60000,
                0.58824,
                0.58039,
                0.56863,
                0.56471,
                0.55686,
                0.54902,
                0.54118,
                0.53333,
                0.52941,
                0.51765,
                0.51373,
                0.50588,
                0.49804,
                0.49412,
                0.49020,
                0.48235,
                0.47843,
                0.46667,
                0.46275,
                0.45882,
                0.45098,
                0.44706,
                0.44314,
                0.43922,
                0.43529,
                0.42745,
                0.41961,
                0.41569,
                0.41176,
                0.40784,
                0.40392,
                0.40000,
                0.39608,
                0.39216,
                0.38824,
                0.38431,
                0.38039,
                0.37255,
                0.36863,
                0.36471,
                0.36078,
                0.35686,
                0.35294,
                0.34902,
                0.34510,
                0.34510,
                0.34118,
                0.33725,
                0.33333,
                0.32941,
                0.32157,
                0.32157,
                0.31765,
                0.31373,
                0.30980,
                0.30980,
                0.30588,
                0.30196,
                0.29804,
                0.29804,
                0.29412,
                0.29020,
                0.28627,
                0.28627,
                0.28235,
                0.27843,
                0.27843,
                0.27059,
                0.26667,
                0.26667,
                0.26275,
                0.25882,
                0.25882,
                0.25490,
                0.25490,
                0.25098,
                0.24706,
                0.24706,
                0.24314,
                0.23922,
                0.23922,
                0.23529,
                0.23529,
                0.23137,
                0.23137,
                0.22745,
                0.21961,
                0.21961,
                0.21569,
                0.21569,
                0.21176,
                0.21176,
                0.20784,
                0.20784,
                0.20392,
                0.20392,
                0.20000,
                0.20000,
                0.19608,
                0.19608,
                0.19216,
                0.19216,
                0.18824,
                0.18824,
                0.18431,
                0.18431,
                0.18039,
                0.18039,
                0.17255,
                0.17255,
                0.16863,
                0.16863,
                0.16471,
                0.16471,
                0.16078,
                0.16078,
                0.16078,
                0.15686,
                0.15686,
                0.15294,
                0.15294,
                0.14902,
                0.14902,
                0.14510,
                0.14510,
                0.14510,
                0.14118,
                0.14118,
                0.13725,
                0.13725,
                0.13725,
                0.13333,
                0.13333,
                0.12941,
                0.12941,
                0.12941,
                0.12157,
                0.12157,
                0.11765,
                0.11765,
                0.11765,
                0.11373,
                0.11373,
                0.10980,
                0.10980,
                0.10980,
                0.10588,
                0.10588,
                0.10588,
                0.10196,
                0.10196,
                0.10196,
                0.09804,
                0.09804,
                0.09412,
                0.09412,
                0.09412,
                0.09020,
                0.09020,
                0.09020,
                0.08627,
                0.08627,
                0.08627,
                0.08235,
                0.08235,
                0.08235,
                0.07843,
                0.07843,
                0.07843,
                0.07059,
                0.07059,
                0.07059,
                0.06667,
                0.06667,
                0.06667,
                0.06275,
                0.06275,
                0.06275,
                0.05882,
                0.05882,
                0.05882,
                0.05882,
                0.05490,
                0.05490,
                0.05490,
                0.05098,
                0.05098,
                0.05098,
                0.04706,
                0.04706,
                0.04706,
                0.04314,
                0.04314,
                0.04314,
                0.04314,
                0.03922,
                0.03922,
                0.03922,
                0.03529,
                0.03529,
                0.03529,
                0.03529,
                0.03137,
                0.03137,
                0.03137,
                0.02745,
                0.02745,
                0.02745,
                0.02745,
                0.01961,
                0.01961,
                0.01961,
                0.01961,
                0.01569,
                0.01569,
                0.01569,
                0.01176,
                0.01176,
                0.01176,
                0.01176,
                0.00784,
                0.00784,
                0.00784,
                0.00784,
                0.00392,
                0.00392,
                0.00392,
                0.00392,
                0.00000,
                0.00000,
                0.00000,
        )

imap_log = (
                0.00000,
                0.01961,
                0.05490,
                0.08627,
                0.10980,
                0.13725,
                0.15686,
                0.18039,
                0.20000,
                0.21569,
                0.23529,
                0.25098,
                0.26275,
                0.28235,
                0.29412,
                0.30588,
                0.31765,
                0.33333,
                0.34118,
                0.35294,
                0.36078,
                0.37255,
                0.38431,
                0.39216,
                0.40000,
                0.41176,
                0.41961,
                0.43137,
                0.43529,
                0.44314,
                0.45098,
                0.45882,
                0.46667,
                0.47059,
                0.48235,
                0.48627,
                0.49412,
                0.50196,
                0.50588,
                0.50980,
                0.51765,
                0.52157,
                0.53333,
                0.53725,
                0.54118,
                0.54902,
                0.55294,
                0.55686,
                0.56078,
                0.56471,
                0.57255,
                0.58039,
                0.58431,
                0.58824,
                0.59216,
                0.59608,
                0.60000,
                0.60392,
                0.60784,
                0.61176,
                0.61569,
                0.61961,
                0.62745,
                0.63137,
                0.63529,
                0.63922,
                0.64314,
                0.64706,
                0.65098,
                0.65490,
                0.65490,
                0.65882,
                0.66275,
                0.66667,
                0.67059,
                0.67843,
                0.67843,
                0.68235,
                0.68627,
                0.69020,
                0.69020,
                0.69412,
                0.69804,
                0.70196,
                0.70196,
                0.70588,
                0.70980,
                0.71373,
                0.71373,
                0.71765,
                0.72157,
                0.72157,
                0.72941,
                0.73333,
                0.73333,
                0.73725,
                0.74118,
                0.74118,
                0.74510,
                0.74510,
                0.74902,
                0.75294,
                0.75294,
                0.75686,
                0.76078,
                0.76078,
                0.76471,
                0.76471,
                0.76863,
                0.76863,
                0.77255,
                0.78039,
                0.78039,
                0.78431,
                0.78431,
                0.78824,
                0.78824,
                0.79216,
                0.79216,
                0.79608,
                0.79608,
                0.80000,
                0.80000,
                0.80392,
                0.80392,
                0.80784,
                0.80784,
                0.81176,
                0.81176,
                0.81569,
                0.81569,
                0.81961,
                0.81961,
                0.82745,
                0.82745,
                0.83137,
                0.83137,
                0.83529,
                0.83529,
                0.83922,
                0.83922,
                0.83922,
                0.84314,
                0.84314,
                0.84706,
                0.84706,
                0.85098,
                0.85098,
                0.85490,
                0.85490,
                0.85490,
                0.85882,
                0.85882,
                0.86275,
                0.86275,
                0.86275,
                0.86667,
                0.86667,
                0.87059,
                0.87059,
                0.87059,
                0.87843,
                0.87843,
                0.88235,
                0.88235,
                0.88235,
                0.88627,
                0.88627,
                0.89020,
                0.89020,
                0.89020,
                0.89412,
                0.89412,
                0.89412,
                0.89804,
                0.89804,
                0.89804,
                0.90196,
                0.90196,
                0.90588,
                0.90588,
                0.90588,
                0.90980,
                0.90980,
                0.90980,
                0.91373,
                0.91373,
                0.91373,
                0.91765,
                0.91765,
                0.91765,
                0.92157,
                0.92157,
                0.92157,
                0.92941,
                0.92941,
                0.92941,
                0.93333,
                0.93333,
                0.93333,
                0.93725,
                0.93725,
                0.93725,
                0.94118,
                0.94118,
                0.94118,
                0.94118,
                0.94510,
                0.94510,
                0.94510,
                0.94902,
                0.94902,
                0.94902,
                0.95294,
                0.95294,
                0.95294,
                0.95686,
                0.95686,
                0.95686,
                0.95686,
                0.96078,
                0.96078,
                0.96078,
                0.96471,
                0.96471,
                0.96471,
                0.96471,
                0.96863,
                0.96863,
                0.96863,
                0.97255,
                0.97255,
                0.97255,
                0.97255,
                0.98039,
                0.98039,
                0.98039,
                0.98039,
                0.98431,
                0.98431,
                0.98431,
                0.98824,
                0.98824,
                0.98824,
                0.98824,
                0.99216,
                0.99216,
                0.99216,
                0.99216,
                0.99608,
                0.99608,
                0.99608,
                0.99608,
                1.00000,
                1.00000,
                1.00000,
        )

imap_gamma = (
                0.11285,
                0.13544,
                0.15416,
                0.17045,
                0.18502,
                0.19831,
                0.21059,
                0.22206,
                0.23284,
                0.24304,
                0.25275,
                0.26202,
                0.27090,
                0.27945,
                0.28768,
                0.29564,
                0.30334,
                0.31081,
                0.31807,
                0.32513,
                0.33201,
                0.33872,
                0.34526,
                0.35167,
                0.35793,
                0.36406,
                0.37007,
                0.37596,
                0.38173,
                0.38741,
                0.39298,
                0.39846,
                0.40385,
                0.40915,
                0.41437,
                0.41952,
                0.42458,
                0.42957,
                0.43449,
                0.43935,
                0.44414,
                0.44887,
                0.45353,
                0.45814,
                0.46270,
                0.46720,
                0.47165,
                0.47604,
                0.48039,
                0.48469,
                0.48894,
                0.49315,
                0.49732,
                0.50144,
                0.50552,
                0.50957,
                0.51357,
                0.51754,
                0.52146,
                0.52536,
                0.52922,
                0.53304,
                0.53683,
                0.54059,
                0.54432,
                0.54801,
                0.55168,
                0.55531,
                0.55892,
                0.56250,
                0.56605,
                0.56958,
                0.57307,
                0.57655,
                0.57999,
                0.58342,
                0.58681,
                0.59019,
                0.59354,
                0.59686,
                0.60017,
                0.60345,
                0.60671,
                0.60995,
                0.61317,
                0.61637,
                0.61955,
                0.62271,
                0.62584,
                0.62896,
                0.63206,
                0.63515,
                0.63821,
                0.64126,
                0.64429,
                0.64730,
                0.65029,
                0.65327,
                0.65623,
                0.65918,
                0.66211,
                0.66502,
                0.66792,
                0.67080,
                0.67367,
                0.67652,
                0.67936,
                0.68218,
                0.68499,
                0.68778,
                0.69057,
                0.69333,
                0.69609,
                0.69883,
                0.70156,
                0.70427,
                0.70697,
                0.70966,
                0.71234,
                0.71501,
                0.71766,
                0.72030,
                0.72293,
                0.72555,
                0.72815,
                0.73075,
                0.73333,
                0.73591,
                0.73847,
                0.74102,
                0.74356,
                0.74609,
                0.74861,
                0.75112,
                0.75361,
                0.75610,
                0.75858,
                0.76105,
                0.76351,
                0.76596,
                0.76840,
                0.77083,
                0.77325,
                0.77566,
                0.77806,
                0.78046,
                0.78284,
                0.78522,
                0.78759,
                0.78994,
                0.79229,
                0.79464,
                0.79697,
                0.79929,
                0.80161,
                0.80392,
                0.80622,
                0.80851,
                0.81079,
                0.81307,
                0.81534,
                0.81760,
                0.81985,
                0.82210,
                0.82434,
                0.82657,
                0.82879,
                0.83101,
                0.83322,
                0.83542,
                0.83762,
                0.83980,
                0.84198,
                0.84416,
                0.84633,
                0.84849,
                0.85064,
                0.85279,
                0.85493,
                0.85706,
                0.85919,
                0.86131,
                0.86343,
                0.86553,
                0.86764,
                0.86973,
                0.87182,
                0.87391,
                0.87598,
                0.87806,
                0.88012,
                0.88218,
                0.88424,
                0.88628,
                0.88833,
                0.89036,
                0.89239,
                0.89442,
                0.89644,
                0.89845,
                0.90046,
                0.90246,
                0.90446,
                0.90645,
                0.90844,
                0.91042,
                0.91240,
                0.91437,
                0.91634,
                0.91830,
                0.92025,
                0.92221,
                0.92415,
                0.92609,
                0.92803,
                0.92996,
                0.93189,
                0.93381,
                0.93572,
                0.93763,
                0.93954,
                0.94144,
                0.94334,
                0.94523,
                0.94712,
                0.94901,
                0.95088,
                0.95276,
                0.95463,
                0.95649,
                0.95836,
                0.96021,
                0.96206,
                0.96391,
                0.96576,
                0.96760,
                0.96943,
                0.97126,
                0.97309,
                0.97491,
                0.97673,
                0.97854,
                0.98035,
                0.98216,
                0.98396,
                0.98576,
                0.98755,
                0.98934,
                0.99113,
                0.99291,
                0.99469,
                0.99646,
                0.99823,
                1.00000,
                1.00000,
                1.00000,
        )

imap_null = (
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
                0.00000,
        )

class IntensityMap(object):
    def __init__(self, name, ilst):
        self.name = name
        #self.arr = numpy.array(ilst)
        self.ilst = ilst

def add_imap(name, ilst):
    global imaps
    imaps[name] = IntensityMap(name, ilst)

def get_imap(name):
    """Get an intensity map array.  May raise a KeyError if a map of the given name
    does not exist.
    """
    return imaps[name]

def get_names():
    res = list(imaps.keys())
    res.sort()
    return res

imaps = {}
for name, value in list(globals().items()):
    if name.startswith('imap_'):
        key = name[5:]
        add_imap(key, value)

#END
